@@ -7,6 +7,7 @@ from openbox.core.sync_batch_advisor import SyncBatchAdvisor
 from openbox.core.async_batch_advisor import AsyncBatchAdvisor
 from openbox.optimizer.base import BOBase
 from openbox.core.message_queue.master_messager import MasterMessager
+from openbox.core.base import Observation
 
 
 class mqSMBO(BOBase):
@@ -97,7 +98,6 @@ class mqSMBO(BOBase):
 
             # Get results from workerQueue.
             while True:
-                # Observation: config, trial_state, constraints, objs, elapsed_time
                 observation = self.master_messager.receive_message()
                 if observation is None:
                     # Wait for workers.
@@ -106,8 +106,9 @@ class mqSMBO(BOBase):
                     break
                 # Report result.
                 result_num += 1
-                if observation[3] is None:  # objs
-                    observation[3] = self.FAILED_PERF
+                config, trial_state, constraints, objs, elapsed_time = observation
+                if objs is None:
+                    observation = Observation(config, trial_state, constraints, self.FAILED_PERF, elapsed_time)
                 self.config_advisor.update_observation(observation)
                 self.logger.info('Master: Get %d observation: %s' % (result_num, str(observation)))
 
@@ -127,7 +128,6 @@ class mqSMBO(BOBase):
             result_num = 0
             result_needed = len(configs)
             while True:
-                # Observation: config, trial_state, constraints, objs, elapsed_time
                 observation = self.master_messager.receive_message()
                 if observation is None:
                     # Wait for workers.
@@ -136,8 +136,9 @@ class mqSMBO(BOBase):
                     continue
                 # Report result.
                 result_num += 1
-                if observation[3] is None:  # objs
-                    observation[3] = self.FAILED_PERF
+                config, trial_state, constraints, objs, elapsed_time = observation
+                if objs is None:
+                    observation = Observation(config, trial_state, constraints, self.FAILED_PERF, elapsed_time)
                 self.config_advisor.update_observation(observation)
                 self.logger.info('Master: In the %d-th batch [%d], observation is: %s'
                                  % (batch_id, result_num, str(observation)))
